@@ -1,9 +1,9 @@
-from __future__ import unicode_literals, absolute_import
+from __future__ import absolute_import, unicode_literals
+
 import os
 import unittest
-from six import PY2
 
-from ics.parse import string_to_container
+from ics.grammar.parse import string_to_container
 
 
 class TestFunctional(unittest.TestCase):
@@ -13,9 +13,6 @@ class TestFunctional(unittest.TestCase):
         cal = os.path.join(os.path.dirname(__file__), "gehol", "BA1.ics")
         with open(cal) as ics:
             ics = ics.read()
-            if PY2:
-                ics = ics.decode('utf-8')
-
             ics = string_to_container(ics)[0]
             self.assertTrue(ics)
 
